@@ -99,26 +99,51 @@ class ClicksignApiTransport(PeasantTransport):
                 "api/v1/accounts",
                 self._access_token
             ),
+            "create_signer": "%s/%s?access_token=%s" % (
+                self._bastion_address,
+                "api/v1/signers",
+                self._access_token
+            ),
+            "create_list": "%s/%s?access_token=%s" % (
+                self._bastion_address,
+                "api/v1/lists",
+                self._access_token
+            ),
+            "notify_by_email": "%s/%s?access_token=%s" % (
+                self._bastion_address,
+                "api/v1/notifications",
+                self._access_token
+            ),
+            "notify_by_whatsapp": "%s/%s?access_token=%s" % (
+                self._bastion_address,
+                "api/v1/notify_by_whatsapp",
+                self._access_token
+            ),
+            "notify_by_sms": "%s/%s?access_token=%s" % (
+                self._bastion_address,
+                "api/v1/notify_by_sms",
+                self._access_token
+            ),
+            "sign": "%s/%s?access_token=%s" % (
+                self._bastion_address,
+                "api/v1/sign",
+                self._access_token
+            ),
+            "read_document": "%s/%s/{0}?access_token=%s" % (
+                self._bastion_address,
+                "api/v1/documents",
+                self._access_token
+            ),
+            "read_documents": "%s/%s?{0}&access_token=%s" % (
+                self._bastion_address,
+                "api/v1/documents",
+                self._access_token
+            ),
             "upload_document": "%s/%s?access_token=%s" % (
                 self._bastion_address,
                 "api/v1/documents",
                 self._access_token
             ),
-            "create_signer": "%s/%s?access_token=%s" % (
-                self._bastion_address,
-                "/api/v1/signers",
-                self._access_token
-            ),
-            "create_list": "%s/%s?access_token=%s" % (
-                self._bastion_address,
-                "/api/v1/lists",
-                self._access_token
-            ),
-            "sign": "%s/%s?access_token=%s" % (
-                self._bastion_address,
-                "/api/v1/sign",
-                self._access_token
-            )
         }
 
 
@@ -203,7 +228,7 @@ class ClicksignPeasant(AsyncPeasant):
                                        "de autenticação(parâmetro auth) "
                                        "contiverem sms e/ou whatsapp.")
 
-        has_documentation = kwargs.get("has_documentation", False)
+        has_documentation = kwargs.get("has_documentation", True)
         selfie_enabled = kwargs.get("selfie_enabled", False)
         handwritten_enabled = kwargs.get("handwritten_enabled", False)
         official_document_enabled = kwargs.get(
@@ -287,6 +312,61 @@ class ClicksignPeasant(AsyncPeasant):
             directory['create_list'], headers=headers,
             form_data=list_data)
 
+    async def notify_by_email(self, request_signature_key,
+                              **kwargs) -> HTTPResponse:
+
+        if not request_signature_key:
+            raise HTTPClientError(400, "É necessário informar a chave da "
+                                       "requisição da assinatura("
+                                       "request_signature_key) para solicitar"
+                                       "a assinatura de um documento.")
+        message = kwargs.get("message", None)
+        url = kwargs.get("url", None)
+
+        notification_data = {
+            'request_signature_key': request_signature_key,
+            'message': message,
+            'url': url
+        }
+        directory = await self.directory()
+        headers = {
+            'Content-Type': "application/json",
+            'Accept': "application/json"
+        }
+        return await self.transport.post(
+            directory['notify_by_email'], headers=headers,
+            form_data=notification_data)
+
+    async def notify_by_whatsapp(self, request_signature_key) -> HTTPResponse:
+        if not request_signature_key:
+            raise HTTPClientError(400, "É necessário informar a chave da "
+                                       "requisição da assinatura("
+                                       "request_signature_key) para solicitar"
+                                       "a assinatura de um documento.")
+        notification_data = {
+            'request_signature_key': request_signature_key
+        }
+        directory = await self.directory()
+        headers = {'Content-Type': "application/json"}
+        return await self.transport.post(
+            directory['notify_by_whatsapp'], headers=headers,
+            form_data=notification_data)
+
+    async def notify_by_sms(self, request_signature_key) -> HTTPResponse:
+        if not request_signature_key:
+            raise HTTPClientError(400, "É necessário informar a chave da "
+                                       "requisição da assinatura("
+                                       "request_signature_key) para solicitar"
+                                       "a assinatura de um documento.")
+        notification_data = {
+            'request_signature_key': request_signature_key
+        }
+        directory = await self.directory()
+        headers = {'Content-Type': "application/json"}
+        return await self.transport.post(
+            directory['notify_by_sms'], headers=headers,
+            form_data=notification_data)
+
     async def sign(self, request_signature_key, secret,
                    **kwargs) -> HTTPResponse:
         if not request_signature_key:
@@ -310,3 +390,15 @@ class ClicksignPeasant(AsyncPeasant):
         return await self.transport.post(
             directory['sign'], headers=headers,
             form_data=list_data)
+
+    async def read_document(self, document_key, **kwargs) -> HTTPResponse:
+        if not document_key:
+            raise HTTPClientError(400, "É necessário informar a chave do "
+                                       "documento a ser lido(document_key).")
+        directory = await self.directory()
+        headers = {
+            'Content-Type': "application/json",
+            'Accept': "application/json"
+        }
+        return await self.transport.get(
+            directory['read_document'].format(document_key), headers=headers)
